==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/calculel/op0009.f <==
      SUBROUTINE OP0009(IER)
      IMPLICIT REAL*8 (A-H,O-Z)
      INTEGER IER
C ----------------------------------------------------------------------
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.

C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.

C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================
C MODIF CALCULEL  DATE 05/10/2004   AUTEUR REZETTE C.REZETTE 
C     COMMANDE:  CALC_MATR_ELEM

C ----------------------------------------------------------------------
C     ----- DEBUT COMMUNS NORMALISES  JEVEUX  --------------------------
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
      CHARACTER*32 JEXNUM,JEXNOM,JEXATR
C     ------------------------------------------------------------------
      REAL*8 TIME,TPS(6)
      CHARACTER*1 BASE
      CHARACTER*4 CTYP
      CHARACTER*8 K8B,MODELE,CARA,SIGG,NOMCMP(6),BLAN8
      CHARACTER*8 MATEL,RIGIEL,MASSEL
      CHARACTER*16 TYPE,OPER,SUROPT
      CHARACTER*19 KCHA
      CHARACTER*24 TIME2,MATE,SDTHET,THETA,COMPOR
      LOGICAL EXITIM
      COMPLEX*16 C16B
      DATA NOMCMP/'INST    ','DELTAT  ','THETA   ','KHI     ',
     &     'R       ','RHO     '/
      DATA TPS/0.D0,2*1.D0,3*0.D0/
C DEB ------------------------------------------------------------------
      CALL JEMARQ()
      CALL INFMAJ()

      BASE = 'G'

      CALL GETRES(MATEL,TYPE,OPER)
      BLAN8  = '        '
      RIGIEL = ' '
      MASSEL = ' '
      SIGG = ' '
      CALL GETVID(' ','RIGI_MECA',0,1,1,RIGIEL,N1)
      CALL GETVID(' ','MASS_MECA',0,1,1,MASSEL,N2)
      CALL GETVTX(' ','OPTION',0,1,1,SUROPT,N3)
      CALL GETVID(' ','SIEF_ELGA',0,1,1,SIGG,N4)
      CALL GETVR8(' ','INST',0,1,1,TIME,N5)
      IF (N5.EQ.0) TIME = 0.D0
      CALL GETVIS(' ','MODE_FOURIER',0,1,1,NH,N6)
      KCHA = '&&OP0009.CHARGES'
      CALL MEDOME(MODELE,MATE,CARA,KCHA,NCHA,CTYP,BLAN8)
      CALL JEVEUO(KCHA,'E',ICHA)
      CALL GETVID(' ','THETA',0,1,1,SDTHET,N7)
      CALL GETVR8(' ','PROPAGATION',0,1,1,ALPHA,N8)
      EXITIM = .TRUE.
      TIME2 = '&TIME'

C --- RECUPERATION DU CHAMNO DE THETA DE LA S.D. SDTHET DE TYPE
C --- THETA_GEOM
C     ----------
      IF (N7.NE.0) THEN
        CALL RSEXCH(SDTHET,'THETA',0,THETA,IRET)
        IF (IRET.GT.0) THEN
          CALL UTMESS('F','OP0009','LE CHAMP DE THETA EST INEXISTANT '//
     &                'DANS LA STRUCTURE DE DONNEES '//SDTHET//' DE '//
     &                'TYPE THETA_GEOM .')
        END IF
      END IF


      TPS(1) = TIME

      IF (SUROPT.EQ.'RIGI_MECA') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        CALL MERIME(MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,MATEL,
     &              NH,BASE)

      ELSE IF (SUROPT.EQ.'RIGI_FLUI_STRU') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        CALL MERIFS(MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,MATEL,
     &              NH)

      ELSE IF (SUROPT.EQ.'RIGI_MECA_LAGR') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        CALL MERILA(MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,MATEL,
     &              THETA(1:19),ALPHA)

      ELSE IF (SUROPT.EQ.'RIGI_GEOM') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        CALL MERIGE(MODELE,CARA,SIGG,MATEL,NH)

      ELSE IF (SUROPT.EQ.'RIGI_ROTA') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        CALL MERIRO(MODELE,NCHA,ZK8(ICHA),MATE,EXITIM,TIME,MATEL)

      ELSE IF (SUROPT.EQ.'MASS_MECA') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        COMPOR = ' '
        CALL MEMAME(SUROPT,MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,
     &              COMPOR,MATEL,BASE)

      ELSE IF (SUROPT.EQ.'MASS_FLUI_STRU') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        COMPOR = ' '
        CALL MEMAME(SUROPT,MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,
     &              COMPOR,MATEL,BASE)

      ELSE IF (SUROPT.EQ.'MASS_MECA_DIAG') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        COMPOR = ' '
        CALL MEMAME(SUROPT,MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,
     &              COMPOR,MATEL,BASE)

      ELSE IF ((SUROPT.EQ.'MASS_ID_MDEP_R') .OR.
     &         (SUROPT.EQ.'MASS_ID_MDNS_R')) THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        COMPOR = ' '
        CALL MEMAME(SUROPT,MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,
     &              COMPOR,MATEL,BASE)

      ELSE IF (SUROPT.EQ.'AMOR_MECA') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        CALL MEAMME(SUROPT,MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,
     &              RIGIEL,MASSEL,MATEL)

      ELSE IF (SUROPT.EQ.'IMPE_MECA') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        CALL MEIMME(MODELE,NCHA,ZK8(ICHA),MATE,MATEL)

      ELSE IF (SUROPT.EQ.'ONDE_FLUI') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        CALL MEONME(MODELE,NCHA,ZK8(ICHA),MATE,MATEL)

      ELSE IF (SUROPT.EQ.'RIGI_MECA_HYST') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'MECA') GO TO 10
        CALL MEAMME(SUROPT,MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,
     &              RIGIEL,MASSEL,MATEL)

      ELSE IF (SUROPT.EQ.'RIGI_THER') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'THER') GO TO 10
        CALL MECACT('V',TIME2,'MODELE',MODELE//'.MODELE','INST_R',6,
     &              NOMCMP,IBID,TPS,C16B,K8B)
        CALL MERITH(MODELE,NCHA,ZK8(ICHA),MATE,CARA,TIME2,'NON',MATEL,
     &              NH,BASE)

      ELSE IF (SUROPT.EQ.'MASS_THER') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'THER') GO TO 10
        CALL MECACT('V',TIME2,'MODELE',MODELE//'.MODELE','INST_R',6,
     &              NOMCMP,IBID,TPS,C16B,K8B)
        CALL MEMATH(SUROPT,MODELE,MATE,CARA,TIME2,MATEL)

      ELSE IF ((SUROPT.EQ.'MASS_ID_MTEM_R') .OR.
     &         (SUROPT.EQ.'MASS_ID_MTNS_R')) THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'THER') GO TO 10
        CALL MECACT('V',TIME2,'MODELE',MODELE//'.MODELE','INST_R',6,
     &              NOMCMP,IBID,TPS,C16B,K8B)
        CALL MEMATH(SUROPT,MODELE,MATE,CARA,TIME2,MATEL)

      ELSE IF (SUROPT.EQ.'RIGI_ACOU') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'ACOU') GO TO 10
        CALL MERIAC(MODELE,NCHA,ZK8(ICHA),MATE,MATEL)

      ELSE IF (SUROPT.EQ.'MASS_ACOU') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'ACOU') GO TO 10
        CALL MEMAAC(MODELE,MATE,MATEL)

      ELSE IF (SUROPT.EQ.'AMOR_ACOU') THEN
        IF (NCHA.NE.0 .AND. CTYP.NE.'ACOU') GO TO 10
        CALL MEAMAC(MODELE,NCHA,ZK8(ICHA),MATE,MATEL)

      END IF
      GO TO 20

   10 CONTINUE
      CALL UTMESS('F',OPER,'UNE DES CHARGES N''EST PAS CORRECTE.')
   20 CONTINUE

      CALL JEDETC(' ','&MEAMAC2.LISTE',1)
      CALL JEDETC(' ','&MEAMAC2.REFE',1)

      CALL JEDETC(' ','&MERIAC1.LISTE',1)
      CALL JEDETC(' ','&MERIAC1.REFE',1)
      CALL JEDETC(' ','&MERIAC2.LISTE',1)
      CALL JEDETC(' ','&MERIAC2.REFE',1)

      CALL JEDETC(' ','&MERITH1.LISTE',1)
      CALL JEDETC(' ','&MERITH2.LISTE',1)
      CALL JEDETC(' ','&MERITH3.LISTE',1)
      CALL JEDETC(' ','&MERITH1.REFE',1)
      CALL JEDETC(' ','&MERITH2.REFE',1)
      CALL JEDETC(' ','&MERITH3.REFE',1)

      CALL JEDEMA()
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/calculel/op0009.f <==
      SUBROUTINE OP0009(IER)
      IMPLICIT REAL*8 (A-H,O-Z)
      INTEGER IER
C ----------------------------------------------------------------------
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.

C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.

C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================
C MODIF CALCULEL  DATE 28/01/2005   AUTEUR VABHHTS J.PELLET 
C     COMMANDE:  CALC_MATR_ELEM

C ----------------------------------------------------------------------
C     ----- DEBUT COMMUNS NORMALISES  JEVEUX  --------------------------
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
      CHARACTER*32 JEXNUM,JEXNOM,JEXATR
C     ------------------------------------------------------------------
      REAL*8 TIME,TPS(6)
      CHARACTER*1 BASE
      CHARACTER*4 CTYP
      CHARACTER*8 K8B,MODELE,CARA,SIGG,NOMCMP(6),BLAN8
      CHARACTER*8 MATEL,RIGIEL,MASSEL
      CHARACTER*16 TYPE,OPER,SUROPT
      CHARACTER*19 KCHA
      CHARACTER*24 TIME2,MATE,SDTHET,THETA,COMPOR
      LOGICAL EXITIM
      COMPLEX*16 C16B
      DATA NOMCMP/'INST    ','DELTAT  ','THETA   ','KHI     ',
     &     'R       ','RHO     '/
      DATA TPS/0.D0,2*1.D0,3*0.D0/
C DEB ------------------------------------------------------------------
      CALL JEMARQ()
      CALL INFMAJ()

      BASE = 'G'

      CALL GETRES(MATEL,TYPE,OPER)
      BLAN8  = '        '
      RIGIEL = ' '
      MASSEL = ' '
      SIGG = ' '
      CALL GETVID(' ','RIGI_MECA',0,1,1,RIGIEL,N1)
      CALL GETVID(' ','MASS_MECA',0,1,1,MASSEL,N2)
      CALL GETVTX(' ','OPTION',0,1,1,SUROPT,N3)
      CALL GETVID(' ','SIEF_ELGA',0,1,1,SIGG,N4)
      CALL GETVR8(' ','INST',0,1,1,TIME,N5)
      IF (N5.EQ.0) TIME = 0.D0
      CALL GETVIS(' ','MODE_FOURIER',0,1,1,NH,N6)
      KCHA = '&&OP0009.CHARGES'
      CALL MEDOME(MODELE,MATE,CARA,KCHA,NCHA,CTYP,BLAN8)
      CALL JEVEUO(KCHA,'E',ICHA)
      CALL GETVID(' ','THETA',0,1,1,SDTHET,N7)
      CALL GETVR8(' ','PROPAGATION',0,1,1,ALPHA,N8)
      EXITIM = .TRUE.
      TIME2 = '&TIME'

C --- RECUPERATION DU CHAMNO DE THETA DE LA S.D. SDTHET DE TYPE
C --- THETA_GEOM
C     ----------
      IF (N7.NE.0) THEN
        CALL RSEXCH(SDTHET,'THETA',0,THETA,IRET)
        IF (IRET.GT.0) THEN
          CALL UTMESS('F','OP0009','LE CHAMP DE THETA EST INEXISTANT '//
     &                'DANS LA STRUCTURE DE DONNEES '//SDTHET//' DE '//
     &                'TYPE THETA_GEOM .')
        END IF
      END IF


      TPS(1) = TIME

      IF (SUROPT.EQ.'RIGI_MECA') THEN
        CALL MERIME(MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,MATEL,
     &              NH,BASE)

      ELSE IF (SUROPT.EQ.'RIGI_FLUI_STRU') THEN
        CALL MERIFS(MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,MATEL,
     &              NH)

      ELSE IF (SUROPT.EQ.'RIGI_MECA_LAGR') THEN
        CALL MERILA(MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,MATEL,
     &              THETA(1:19),ALPHA)

      ELSE IF (SUROPT.EQ.'RIGI_GEOM') THEN
        CALL MERIGE(MODELE,CARA,SIGG,MATEL,NH)

      ELSE IF (SUROPT.EQ.'RIGI_ROTA') THEN
        CALL MERIRO(MODELE,NCHA,ZK8(ICHA),MATE,EXITIM,TIME,MATEL)

      ELSE IF (SUROPT.EQ.'MASS_MECA') THEN
        COMPOR = ' '
        CALL MEMAME(SUROPT,MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,
     &              COMPOR,MATEL,BASE)

      ELSE IF (SUROPT.EQ.'MASS_FLUI_STRU') THEN
        COMPOR = ' '
        CALL MEMAME(SUROPT,MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,
     &              COMPOR,MATEL,BASE)

      ELSE IF (SUROPT.EQ.'MASS_MECA_DIAG') THEN
        COMPOR = ' '
        CALL MEMAME(SUROPT,MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,
     &              COMPOR,MATEL,BASE)

      ELSE IF ((SUROPT.EQ.'MASS_ID_MDEP_R') .OR.
     &         (SUROPT.EQ.'MASS_ID_MDNS_R')) THEN
        COMPOR = ' '
        CALL MEMAME(SUROPT,MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,
     &              COMPOR,MATEL,BASE)

      ELSE IF (SUROPT.EQ.'AMOR_MECA') THEN
        CALL MEAMME(SUROPT,MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,
     &              RIGIEL,MASSEL,MATEL)

      ELSE IF (SUROPT.EQ.'IMPE_MECA') THEN
        CALL MEIMME(MODELE,NCHA,ZK8(ICHA),MATE,MATEL)

      ELSE IF (SUROPT.EQ.'ONDE_FLUI') THEN
        CALL MEONME(MODELE,NCHA,ZK8(ICHA),MATE,MATEL)

      ELSE IF (SUROPT.EQ.'RIGI_MECA_HYST') THEN
        CALL MEAMME(SUROPT,MODELE,NCHA,ZK8(ICHA),MATE,CARA,EXITIM,TIME,
     &              RIGIEL,MASSEL,MATEL)

      ELSE IF (SUROPT.EQ.'RIGI_THER') THEN
        CALL MECACT('V',TIME2,'MODELE',MODELE//'.MODELE','INST_R',6,
     &              NOMCMP,IBID,TPS,C16B,K8B)
        CALL MERITH(MODELE,NCHA,ZK8(ICHA),MATE,CARA,TIME2,'NON',MATEL,
     &              NH,BASE)

      ELSE IF (SUROPT.EQ.'MASS_THER') THEN
        CALL MECACT('V',TIME2,'MODELE',MODELE//'.MODELE','INST_R',6,
     &              NOMCMP,IBID,TPS,C16B,K8B)
        CALL MEMATH(SUROPT,MODELE,MATE,CARA,TIME2,MATEL)

      ELSE IF ((SUROPT.EQ.'MASS_ID_MTEM_R') .OR.
     &         (SUROPT.EQ.'MASS_ID_MTNS_R')) THEN
        CALL MECACT('V',TIME2,'MODELE',MODELE//'.MODELE','INST_R',6,
     &              NOMCMP,IBID,TPS,C16B,K8B)
        CALL MEMATH(SUROPT,MODELE,MATE,CARA,TIME2,MATEL)

      ELSE IF (SUROPT.EQ.'RIGI_ACOU') THEN
        CALL MERIAC(MODELE,NCHA,ZK8(ICHA),MATE,MATEL)

      ELSE IF (SUROPT.EQ.'MASS_ACOU') THEN
        CALL MEMAAC(MODELE,MATE,MATEL)

      ELSE IF (SUROPT.EQ.'AMOR_ACOU') THEN
        CALL MEAMAC(MODELE,NCHA,ZK8(ICHA),MATE,MATEL)

      END IF
      GO TO 20

   20 CONTINUE

      CALL JEDETC(' ','&MEAMAC2.LISTE',1)
      CALL JEDETC(' ','&MEAMAC2.REFE',1)

      CALL JEDETC(' ','&MERIAC1.LISTE',1)
      CALL JEDETC(' ','&MERIAC1.REFE',1)
      CALL JEDETC(' ','&MERIAC2.LISTE',1)
      CALL JEDETC(' ','&MERIAC2.REFE',1)

      CALL JEDETC(' ','&MERITH1.LISTE',1)
      CALL JEDETC(' ','&MERITH2.LISTE',1)
      CALL JEDETC(' ','&MERITH3.LISTE',1)
      CALL JEDETC(' ','&MERITH1.REFE',1)
      CALL JEDETC(' ','&MERITH2.REFE',1)
      CALL JEDETC(' ','&MERITH3.REFE',1)

      CALL JEDEMA()
      END
